@@ -2,19 +2,48 @@ import base64
 import binascii
 import pathlib
 import webbrowser
-import pyperclip
-import requests
 import logging
 import inspect
-import jsonpickle
-import ujson
 import io
-import regex as re
+import itertools
 from typing import Any, Tuple, List, Union
 
-from .modules.exceptions import PrintException
+import pyperclip
+import requests
+import ujson
+import jsonpickle
+import regex as re
+import scapy.all as scapy
+from decorator import decorator
 
-logging.getLogger().setLevel(logging.INFO)
+from .modules.exceptions import PrintException
+from .modules.internal.colors import YELLOW, CYAN, GREEN, MAGENTA
+
+
+class ChepyDecorators(object):
+    """A class to house all the decorators for Chepy
+    """
+
+    @staticmethod
+    @decorator
+    def call_stack(func, *args, **kwargs):
+        """This decorator is used to get the method name and 
+        arguments and save it to self.stack. The data from 
+        self.stack is predominantly used to save recepies. 
+        """
+        func_sig = dict()
+        func_self = args[0]
+        func_sig["function"] = func.__name__
+
+        bound_args = inspect.signature(func).bind(*args, **kwargs)
+        bound_args.apply_defaults()
+
+        func_arguments = dict(bound_args.arguments)
+        del func_arguments["self"]
+        func_sig["args"] = func_arguments
+        func_self._stack.append(func_sig)
+
+        return func(*args, **kwargs)
 
 
 class ChepyCore(object):
@@ -39,10 +68,28 @@ class ChepyCore(object):
 
     def __init__(self, *data):
         self.states = dict(list(enumerate(data)))
+        #: Holder for the initial state
+        self.__initial_states = dict(list(enumerate(data)))
+        #: Value of the initial state
         self._current_index = 0
         self.buffers = dict()
         #: Alias for `write_to_file`
         self.write = self.write_to_file
+        #: Alias for `out`
+        self.bake = self.out
+        #: Alias for `web`
+        self.cyberchef = self.web
+        #: Holds all the methods that are called/chanined and their args
+        self._stack = list()
+        #: Holder for scapy pcap reader
+        self._pcap_filepath = None
+
+        #: Log level
+        self.log_level = logging.INFO
+        #: Log format message
+        self.log_format = "%(levelname)-2s - %(message)s"
+        logging.getLogger().setLevel(self.log_level)
+        logging.basicConfig(format=self.log_format)
 
     @property
     def state(self):
@@ -98,9 +145,9 @@ class ChepyCore(object):
             path (str): Path to expand
         
         Returns:
-            str: Expanded absolute path
+            object: Path object
         """
-        return str(pathlib.Path(path).expanduser().absolute())
+        return pathlib.Path(path).expanduser().absolute()
 
     def _info_logger(self, data: str) -> None:
         """Just a binding for logger.info
@@ -114,6 +161,18 @@ class ChepyCore(object):
         logging.info(data)
         return None
 
+    def _warning_logger(self, data: str) -> None:  # pragma: no cover
+        """Just a binding for logger.warning
+        
+        Args:
+            data (str): Message to log
+        
+        Returns:
+            Chepy: The Chepy object. 
+        """
+        logging.warning(data)
+        return None
+
     def fork(self, methods: List[Tuple[Union[str, object], dict]]):
         """Run multiple methods on all available states
         
@@ -156,6 +215,7 @@ class ChepyCore(object):
                     self.states[i] = getattr(self, method_name)().o
         return self
 
+    @ChepyDecorators.call_stack
     def set_state(self, data: Any):
         """Set any arbitrary values in the current state
 
@@ -179,6 +239,7 @@ class ChepyCore(object):
         self.state = data
         return self
 
+    @ChepyDecorators.call_stack
     def create_state(self):
         """Create a new empty state
         
@@ -188,6 +249,7 @@ class ChepyCore(object):
         self.states[len(self.states)] = {}
         return self
 
+    @ChepyDecorators.call_stack
     def copy_state(self, index: int):
         """Copy the current state to a new state
         
@@ -200,6 +262,7 @@ class ChepyCore(object):
         self.states[index] = self.states.get(self._current_index)
         return self
 
+    @ChepyDecorators.call_stack
     def change_state(self, index: int):
         """Change current state by index
 
@@ -219,6 +282,7 @@ class ChepyCore(object):
         self._current_index = index
         return self
 
+    @ChepyDecorators.call_stack
     def switch_state(self, index: int):  # pragma: no cover
         """Switch current state by index
 
@@ -238,6 +302,7 @@ class ChepyCore(object):
         self._current_index = index
         return self
 
+    @ChepyDecorators.call_stack
     def delete_state(self, index: int):
         """Delete a state specified by the index
         
@@ -253,6 +318,21 @@ class ChepyCore(object):
             logging.warning("{} does not exist".format(index))
         return self
 
+    @ChepyDecorators.call_stack
+    def get_state(self, index: int) -> Any:
+        """Returns the value of the specified state. 
+
+        This method does not chain with other methods of Chepy
+        
+        Args:
+            index (int): The index of the state
+        
+        Returns:
+            Any: Any value that is in the specified state
+        """
+        return self.states.get(index)
+
+    @ChepyDecorators.call_stack
     def save_buffer(self, index: int = None):
         """Save current state in a buffer 
 
@@ -273,6 +353,7 @@ class ChepyCore(object):
             self.buffers[len(self.buffers)] = self.state
         return self
 
+    @ChepyDecorators.call_stack
     def load_buffer(self, index: int):
         """Load the specified buffer into state
         
@@ -299,6 +380,7 @@ class ChepyCore(object):
         self.state = self.buffers[index]
         return self
 
+    @ChepyDecorators.call_stack
     def delete_buffer(self, index: int):
         """Delete a buffer item
         
@@ -314,6 +396,7 @@ class ChepyCore(object):
             logging.warning("{} does not exist".format(index))
         return self
 
+    @ChepyDecorators.call_stack
     def substring(self, pattern: str, group: int = 0):
         """Choose a substring from current state as string 
 
@@ -330,19 +413,6 @@ class ChepyCore(object):
         self.state = re.search(pattern, self._convert_to_str()).group(group)
         return self
 
-    def get_state(self, index: int) -> Any:
-        """Returns the value of the specified state. 
-
-        This method does not chain with other methods of Chepy
-        
-        Args:
-            index (int): The index of the state
-        
-        Returns:
-            Any: Any value that is in the specified state
-        """
-        return self.states.get(index)
-
     def _convert_to_bytes(self) -> None:
         """This method is used to coerce the curret object in 
         the state variable into a string. The method should be 
@@ -440,6 +510,7 @@ class ChepyCore(object):
         """
         return self.state
 
+    @ChepyDecorators.call_stack
     def out(self) -> Any:
         """Get the final output
         
@@ -448,6 +519,7 @@ class ChepyCore(object):
         """
         return self.state
 
+    @ChepyDecorators.call_stack
     def out_as_str(self) -> str:
         """Get current value as str
         
@@ -456,6 +528,7 @@ class ChepyCore(object):
         """
         return self._convert_to_str()
 
+    @ChepyDecorators.call_stack
     def out_as_bytes(self) -> bytes:
         """Get current value as bytes
         
@@ -464,6 +537,7 @@ class ChepyCore(object):
         """
         return self._convert_to_bytes()
 
+    @ChepyDecorators.call_stack
     def get_by_index(self, index: int):
         """Get an item by specifying an index
         
@@ -476,6 +550,7 @@ class ChepyCore(object):
         self.state = self.state[index]
         return self
 
+    @ChepyDecorators.call_stack
     def get_by_key(self, key: str):
         """Get an object from a dict by key
         
@@ -491,6 +566,7 @@ class ChepyCore(object):
         else:  # pragma: no cover
             raise TypeError("State is not a dictionary")
 
+    @ChepyDecorators.call_stack
     def copy_to_clipboard(self) -> None:  # pragma: no cover
         """Copy to clipboard
         
@@ -503,6 +579,7 @@ class ChepyCore(object):
         pyperclip.copy(self._convert_to_str())
         return None
 
+    @ChepyDecorators.call_stack
     def copy(self) -> None:  # pragma: no cover
         """Copy to clipboard
         
@@ -515,6 +592,7 @@ class ChepyCore(object):
         self.copy_to_clipboard()
         return None
 
+    @ChepyDecorators.call_stack
     def web(self, magic: bool = False) -> None:  # pragma: no cover
         """Opens the current string in CyberChef on the browser as hex
 
@@ -538,6 +616,7 @@ class ChepyCore(object):
         webbrowser.open_new_tab(url)
         return None
 
+    @ChepyDecorators.call_stack
     def http_request(
         self,
         method: str = "GET",
@@ -611,6 +690,7 @@ class ChepyCore(object):
         }
         return self
 
+    @ChepyDecorators.call_stack
     def load_dir(self, pattern: str = "*"):
         """Load all file paths in a directory
         
@@ -627,6 +707,7 @@ class ChepyCore(object):
         }
         return self
 
+    @ChepyDecorators.call_stack
     def load_file(self):
         """If a path is provided, read the file
         
@@ -647,6 +728,7 @@ class ChepyCore(object):
                 self.states[self._current_index] = bytearray(f.read())
         return self
 
+    @ChepyDecorators.call_stack
     def read_file(self):
         """If a path is provided, read the file 
 
@@ -658,11 +740,11 @@ class ChepyCore(object):
         self.load_file()
         return self
 
-    def write_to_file(self, file_path: str, as_binary: bool = False) -> None:
+    def write_to_file(self, path: str, as_binary: bool = False) -> None:
         """Save the state to disk. Return None.
         
         Args:
-            file_path (str): The file path to save in.
+            path (str): The file path to save in.
             as_binary (bool, optional): If file should be saved as a binary file. Defaults to False.
         
         Returns:
@@ -677,16 +759,18 @@ class ChepyCore(object):
             mode = "wb+"
         else:
             mode = "w+"
-        with open(str(self._abs_path(file_path)), mode) as f:
+        if isinstance(path, bytes):  # pragma: no cover
+            path = path.decode()
+        with open(str(self._abs_path(path)), mode) as f:
             f.write(self.state)
-        self._info_logger("File written to {}".format(self._abs_path(file_path)))
+        self._info_logger("File written to {}".format(self._abs_path(path)))
         return None
 
-    def write_binary(self, file_path: str) -> None:  # pragma: no cover
+    def write_binary(self, path: str) -> None:  # pragma: no cover
         """Save the state to disk. Return None.
         
         Args:
-            file_path (str): The file path to save in.
+            path (str): The file path to save in.
         
         Returns:
             None: Returns None
@@ -694,7 +778,209 @@ class ChepyCore(object):
         Examples:
             >>> c = Chepy("some data").write_binary('/some/path/file')
         """
-        with open(str(self._abs_path(file_path)), "wb+") as f:
+        if isinstance(path, bytes):  # pragma: no cover
+            path = path.decode()
+        with open(str(self._abs_path(path)), "wb+") as f:
             f.write(self.state)
-        self._info_logger("File written to {}".format(self._abs_path(file_path)))
+        self._info_logger("File written to {}".format(self._abs_path(path)))
         return None
+
+    def save_recipe(self, path: str):
+        """Save the current recipe
+
+        A recipe will be all the previous methdos called on the 
+        chepy instance along with their args
+        
+        Args:
+            path (str): The path to save the recipe
+        
+        Returns:
+            Chepy: The Chepy object. 
+
+        Examples:
+            >>> c = Chepy("some data").to_hex().base64_encode()
+            >>> c.save_recipe("/path/to/recipe)
+            >>> c.out()
+            NzM2ZjZkNjUyMDY0NjE3NDYx
+        """
+        with self._abs_path(path) as f:
+            f.write_text(ujson.dumps(self._stack))
+        self._info_logger("Saved recipe to {}".format(str(path)))
+        return self
+
+    def load_recipe(self, path: str):
+        """Load and run a recipe
+        
+        Args:
+            path (str): Path to recipe file
+        
+        Returns:
+            Chepy: The Chepy object.
+
+        Examples:
+            >>> c = Chepy("some data").load_recipe("/path/to/recipe").out()
+            NzM2ZjZkNjUyMDY0NjE3NDYx
+        """
+        with self._abs_path(path) as f:
+            recipes = ujson.loads(f.read_text())
+            for recipe in recipes:
+                function = recipe["function"]
+                args = recipe["args"]
+                if len(args) > 0:
+                    getattr(self, function)(**args)
+                else:
+                    getattr(self, function)()
+        return self
+
+    @ChepyDecorators.call_stack
+    def loop_list(self, callback: str, args: dict = {}):
+        """Loop over an array and run a Chepy method on it
+        
+        Args:
+            callback (str): Chepy method as string
+            args (dict, optional): Dictionary of args. Defaults to {}.
+        
+        Returns:
+            Chepy: The Chepy object
+
+        Examples:
+            This method is capable of running a callable from either 
+            a string, or a chepy method.
+
+            >>> c = Chepy(["an", "array"])
+            >>> c.loop_list('to_hex').loop_list('hmac_hash', {'key': 'secret'})
+            ['5cbe6ca2a66b380aec1449d4ebb0d40ac5e1b92e', '30d75bf34740e8781cd4ec7b122e3efd8448e270']
+        """
+        assert isinstance(self.state, list), "State is not a list"
+        assert isinstance(callback, str), "Callback must be a"
+        hold = []
+        current_state = self.state
+        # find the last index that this method was run
+        stack_loop_index = next(
+            itertools.dropwhile(
+                lambda x: self._stack[x]["function"] != "loop_list",
+                reversed(range(len(self._stack))),
+            )
+        )
+        try:
+            for index, data in enumerate(current_state):
+                self.state = current_state[index]
+                if args:
+                    hold.append(getattr(self, callback)(**args).o)
+                else:
+                    hold.append(getattr(self, callback)().o)
+            self._stack = self._stack[: stack_loop_index + 1]
+            self.state = hold
+            return self
+        except:  # pragma: no cover
+            self.state = current_state
+            raise
+
+    @ChepyDecorators.call_stack
+    def loop_dict(self, keys: list, callback: str, args: dict = {}):
+        """Loop over a dictionary and apply the callback to the value
+        
+        Args:
+            keys (list): List of keys to match
+            callback (str): Chepy method as string
+            args (dict, optional): Dictionary of args. Defaults to {}.
+        
+        Returns:
+            Chepy: The Chepy object. 
+
+        Examples:
+            >>> c = Chepy({'some': 'hahahaha', 'lol': 'aahahah'})
+            >>> c.loop_dict(['some'], 'hmac_hash', {'key': 'secret'}).o
+            {'some': '99f77ec06a3c69a4a95371a7888245ba57f47f55', 'lol': 'aahahah'}
+            
+            We can combine `loop_list` and `loop_dict` to loop over a list of dictionaries.
+
+            >>> data = [{"some": "val"}, {"some": "another"}, {"lol": "lol"}, {"another": "aaaa"}]
+            >>> c = Chepy(data)
+            >>> c.loop_list("loop_dict", {"keys": ["some", "lol"], "callback": "to_upper_case"})
+            [
+                {"some": "VAL"},
+                {"some": "ANOTHER"},
+                {"lol": "LOL"},
+                {"another": "aaaa"},
+            ]
+        """
+        assert isinstance(keys, list), "Keys needs to be a list of keys"
+        assert isinstance(args, dict), "Args needs to be a dict"
+        assert isinstance(callback, str), "Callback must be a string"
+        hold = {}
+        current_state = self.state
+        # find the last index that this method was run
+        stack_loop_index = next(
+            itertools.dropwhile(
+                lambda x: self._stack[x]["function"] != "loop_dict",
+                reversed(range(len(self._stack))),
+            )
+        )
+        try:
+            dict_keys = current_state.keys()
+            for key in keys:
+                if current_state.get(key) is not None:
+                    self.state = current_state.get(key)
+                    if args:
+                        hold[key] = getattr(self, callback)(**args).o
+                    else:
+                        hold[key] = getattr(self, callback)().o
+            for unmatched_key in list(set(dict_keys) - set(keys)):
+                hold[unmatched_key] = current_state[unmatched_key]
+            self._stack = self._stack[: stack_loop_index + 1]
+            self.state = hold
+            return self
+        except:  # pragma: no cover
+            self.state = current_state
+            raise
+
+    @ChepyDecorators.call_stack
+    def read_pcap(self):
+        """Load a pcap. The state is set to scapy
+        
+        Returns:
+            Chepy: The Chepy object. 
+        """
+        self._pcap_filepath = str(self._abs_path(self.state))
+        self.state = GREEN("Pcap loaded")
+        return self
+
+    @ChepyDecorators.call_stack
+    def debug(self, verbose: bool = False):
+        """Debug the curren instance of Chepy
+        
+        This method does not change the state. 
+
+        Args:
+            verbose (bool, optional): Show verbose info. Defaults to False.
+        
+        Returns:
+            Chepy: The Chepy object. 
+        """
+        print(CYAN("Current state:"), YELLOW(str(self._current_index)))
+        print(CYAN("Current states:"), YELLOW(str(len(self.states))))
+        print(
+            CYAN("Current state types:"),
+            YELLOW(str({k: type(v).__name__ for k, v in self.states.items()})),
+        )
+        print(CYAN("Current buffers:"), YELLOW(str(len(self.buffers))))
+        print(
+            CYAN("Current buffer types:"),
+            YELLOW(str({k: type(v).__name__ for k, v in self.buffers.items()})),
+        )
+        if verbose:
+            print(MAGENTA("States:"), self.states)
+            print(MAGENTA("Buffers:"), self.buffers)
+        return self
+
+    @ChepyDecorators.call_stack
+    def reset(self):
+        """Reset states back to their initial values
+        
+        Returns:
+            Chepy: The Chepy object. 
+        """
+        self.states = self.__initial_states
+        return self
+
