@@ -3,10 +3,11 @@ import unicodedata
 from typing import List
 import regex as re
 
-from ..core import ChepyCore
+from ..core import ChepyCore, ChepyDecorators
 
 
 class Language(ChepyCore):
+    @ChepyDecorators.call_stack
     def unicode_chrs_by_lang(self, lang: str):
         """Detect language specific characters
         
@@ -28,6 +29,7 @@ class Language(ChepyCore):
         self.state = re.findall(r"\p{" + lang + "}", self._convert_to_str())
         return self
 
+    @ChepyDecorators.call_stack
     def find_emojis(self):
         """Find emojis, symbols, pictographs, map symbols and flags
         
@@ -37,6 +39,7 @@ class Language(ChepyCore):
         self.state = emoji.get_emoji_regexp().findall(self._convert_to_str())
         return self
 
+    @ChepyDecorators.call_stack
     def encode_utf_16_le(self):
         """Encode string as UTF16LE (1200). 
         
@@ -48,6 +51,7 @@ class Language(ChepyCore):
         )
         return self
 
+    @ChepyDecorators.call_stack
     def decode_utf_16_le(self):
         """Decode string as UTF16LE (1200). 
         
@@ -57,6 +61,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("utf_16_le")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_utf_16_be(self):
         """Encode string as UTF16BE (1201). 
         
@@ -68,6 +73,7 @@ class Language(ChepyCore):
         )
         return self
 
+    @ChepyDecorators.call_stack
     def decode_utf_16_be(self):
         """Decode string as UTF16BE (1201). 
         
@@ -77,6 +83,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("utf_16_be")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_utf_7(self):
         """Encode string as UTF7. 
         
@@ -86,6 +93,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_str().encode("utf_7", errors="backslashreplace")
         return self
 
+    @ChepyDecorators.call_stack
     def decode_utf_7(self):
         """Decode string as UTF7. 
         
@@ -95,6 +103,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("utf_7")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_cp500(self):
         """Encode string as EBCDIC-CP-BE, EBCDIC-CP-CH, IBM500 or CP500. 
         Western European languages. 
@@ -105,6 +114,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_str().encode("cp500", errors="backslashreplace")
         return self
 
+    @ChepyDecorators.call_stack
     def decode_cp500(self):
         """Decode string as EBCDIC-CP-BE, EBCDIC-CP-CH, IBM500 or CP500. 
         Western European languages.
@@ -115,6 +125,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("cp500")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_cp037(self):
         """Encode IBM037, IBM039. English languages.
         
@@ -124,6 +135,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_str().encode("cp037", errors="backslashreplace")
         return self
 
+    @ChepyDecorators.call_stack
     def decode_cp037(self):
         """Decode IBM037, IBM039. English languages
         
@@ -133,6 +145,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("cp037")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_cp874(self):
         """Encode Windows-874 Thai (874)
         
@@ -142,6 +155,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_str().encode("cp874", errors="backslashreplace")
         return self
 
+    @ChepyDecorators.call_stack
     def decode_cp874(self):
         """Decode Windows-874 Thai (874)
         
@@ -151,6 +165,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("cp874")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_cp932(self):
         """Encode Japanese Shift-JIS (932), 932, ms932, mskanji, ms-kanji	
         
@@ -160,6 +175,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_str().encode("cp932", errors="backslashreplace")
         return self
 
+    @ChepyDecorators.call_stack
     def decode_cp932(self):
         """Decode Japanese Shift-JIS (932), 932, ms932, mskanji, ms-kanji	
         
@@ -169,6 +185,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("cp932")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_gbk(self):
         """Encode Simplified Chinese GBK (936), 936, cp936, ms936
         
@@ -178,6 +195,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_str().encode("gbk", errors="backslashreplace")
         return self
 
+    @ChepyDecorators.call_stack
     def decode_gbk(self):
         """Decode Simplified Chinese GBK (936), 936, cp936, ms936
         
@@ -187,6 +205,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("gbk")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_gb2312(self):
         """Encode Simplified Chinese GB2312 (20936), chinese, csiso58gb231280, 
         euc-cn, euccn, eucgb2312-cn, gb2312-1980, gb2312-80, iso-ir-58
@@ -197,6 +216,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_str().encode("gb2312", errors="backslashreplace")
         return self
 
+    @ChepyDecorators.call_stack
     def decode_gb2312(self):
         """Decode Simplified Chinese GB2312 (20936), chinese, csiso58gb231280, 
         euc-cn, euccn, eucgb2312-cn, gb2312-1980, gb2312-80, iso-ir-58
@@ -207,6 +227,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("gb2312")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_cp949(self):
         """Encode Korean (949), 949, ms949, uhc
         
@@ -216,6 +237,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_str().encode("cp949", errors="backslashreplace")
         return self
 
+    @ChepyDecorators.call_stack
     def decode_cp949(self):
         """Decode Korean (949), 949, ms949, uhc
         
@@ -225,6 +247,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("cp949")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_cp950(self):
         """Encode Traditional Chinese Big5 (950), 950, ms950
         
@@ -234,6 +257,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_str().encode("cp950", errors="backslashreplace")
         return self
 
+    @ChepyDecorators.call_stack
     def decode_cp950(self):
         """Decode Traditional Chinese Big5 (950), 950, ms950
         
@@ -243,6 +267,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("cp950")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_cp1250(self):
         """Encode Windows-1250 Central / Eastern European (1250), windows-1250	
         
@@ -252,6 +277,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_str().encode("cp1250", errors="backslashreplace")
         return self
 
+    @ChepyDecorators.call_stack
     def decode_cp1250(self):
         """Decode Windows-1250 Central / Eastern European (1250), windows-1250	
         
@@ -261,6 +287,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("cp1250")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_cp1251(self):
         """Encode Windows-1251 Cyrillic (1251), windows-1251
         
@@ -270,6 +297,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_str().encode("cp1251", errors="backslashreplace")
         return self
 
+    @ChepyDecorators.call_stack
     def decode_cp1251(self):
         """Decode Windows-1251 Cyrillic (1251), windows-1251
         
@@ -279,6 +307,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("cp1251")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_cp1252(self):
         """Encode Windows-1252 Latin (1252)
         
@@ -288,6 +317,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_str().encode("cp1252", errors="backslashreplace")
         return self
 
+    @ChepyDecorators.call_stack
     def decode_cp1252(self):
         """Decode Windows-1252 Latin (1252)
         
@@ -297,6 +327,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("cp1252")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_cp1253(self):
         """Encode Windows-1253 Greek (1253)
         
@@ -306,6 +337,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_str().encode("cp1253", errors="backslashreplace")
         return self
 
+    @ChepyDecorators.call_stack
     def decode_cp1253(self):
         """Decode Windows-1253 Greek (1253)
         
@@ -315,6 +347,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("cp1253")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_cp1254(self):
         """Encode Windows-1254 Turkish (1254)
         
@@ -324,6 +357,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_str().encode("cp1254", errors="backslashreplace")
         return self
 
+    @ChepyDecorators.call_stack
     def decode_cp1254(self):
         """Decode Windows-1254 Turkish (1254)
         
@@ -333,6 +367,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("cp1254")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_cp1255(self):
         """Encode Windows-1255 Hebrew (1255)
         
@@ -342,6 +377,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_str().encode("cp1255", errors="backslashreplace")
         return self
 
+    @ChepyDecorators.call_stack
     def decode_cp1255(self):
         """Decode Windows-1255 Hebrew (1255)
         
@@ -351,6 +387,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("cp1255")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_cp1256(self):
         """Encode Windows-1256 Arabic (1256)
         
@@ -360,6 +397,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_str().encode("cp1256", errors="backslashreplace")
         return self
 
+    @ChepyDecorators.call_stack
     def decode_cp1256(self):
         """Decode Windows-1256 Arabic (1256)
         
@@ -369,6 +407,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("cp1256")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_cp1257(self):
         """Encode Windows-1257 Baltic (1257)
         
@@ -378,6 +417,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_str().encode("cp1257", errors="backslashreplace")
         return self
 
+    @ChepyDecorators.call_stack
     def decode_cp1257(self):
         """Decode Windows-1257 Baltic (1257)
         
@@ -387,6 +427,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("cp1257")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_cp1258(self):
         """Encode Windows-1258 Vietnam (1258)
         
@@ -396,6 +437,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_str().encode("cp1258", errors="backslashreplace")
         return self
 
+    @ChepyDecorators.call_stack
     def decode_cp1258(self):
         """Decode Windows-1258 Vietnam (1258)
         
@@ -405,6 +447,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("cp1258")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_iso8859_2(self):
         """Encode ISO-8859-2 Latin 2 Central European (28592)
         
@@ -416,6 +459,7 @@ class Language(ChepyCore):
         )
         return self
 
+    @ChepyDecorators.call_stack
     def decode_iso8859_2(self):
         """Decode ISO-8859-2 Latin 2 Central European (28592)
         
@@ -425,6 +469,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("iso8859_2")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_iso8859_3(self):
         """Encode ISO-8859-3 Latin 3 South European (28593)
         
@@ -436,6 +481,7 @@ class Language(ChepyCore):
         )
         return self
 
+    @ChepyDecorators.call_stack
     def decode_iso8859_3(self):
         """Decode ISO-8859-3 Latin 3 South European (28593)
         
@@ -445,6 +491,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("iso8859_3")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_iso8859_4(self):
         """Encode ISO-8859-4 Latin 4 North European (28594)
         
@@ -456,6 +503,7 @@ class Language(ChepyCore):
         )
         return self
 
+    @ChepyDecorators.call_stack
     def decode_iso8859_4(self):
         """Decode ISO-8859-4 Latin 4 North European (28594)
         
@@ -465,6 +513,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("iso8859_4")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_iso8859_5(self):
         """Encode ISO-8859-5 Latin/Cyrillic (28595)
         
@@ -476,6 +525,7 @@ class Language(ChepyCore):
         )
         return self
 
+    @ChepyDecorators.call_stack
     def decode_iso8859_5(self):
         """Decode ISO-8859-5 Latin/Cyrillic (28595)
         
@@ -485,6 +535,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("iso8859_5")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_iso8859_6(self):
         """Encode ISO-8859-6 Latin/Arabic (28596)
         
@@ -496,6 +547,7 @@ class Language(ChepyCore):
         )
         return self
 
+    @ChepyDecorators.call_stack
     def decode_iso8859_6(self):
         """Decode ISO-8859-6 Latin/Arabic (28596)
         
@@ -505,6 +557,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("iso8859_6")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_iso8859_7(self):
         """Encode ISO-8859-7 Latin/Greek (28597)
         
@@ -516,6 +569,7 @@ class Language(ChepyCore):
         )
         return self
 
+    @ChepyDecorators.call_stack
     def decode_iso8859_7(self):
         """Decode ISO-8859-7 Latin/Greek (28597)
         
@@ -525,6 +579,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("iso8859_7")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_iso8859_8(self):
         """Encode ISO-8859-8 Latin/Hebrew (28598)
         
@@ -536,6 +591,7 @@ class Language(ChepyCore):
         )
         return self
 
+    @ChepyDecorators.call_stack
     def decode_iso8859_8(self):
         """Decode ISO-8859-8 Latin/Hebrew (28598)
         
@@ -545,6 +601,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("iso8859_8")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_iso8859_9(self):
         """Encode ISO-8859-9 Latin 5 Turkish (28599)
         
@@ -556,6 +613,7 @@ class Language(ChepyCore):
         )
         return self
 
+    @ChepyDecorators.call_stack
     def decode_iso8859_9(self):
         """Decode ISO-8859-9 Latin 5 Turkish (28599)
         
@@ -565,6 +623,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("iso8859_9")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_iso8859_10(self):
         """Encode ISO-8859-10 Latin 6 Nordic (28600)
         
@@ -576,6 +635,7 @@ class Language(ChepyCore):
         )
         return self
 
+    @ChepyDecorators.call_stack
     def decode_iso8859_10(self):
         """Decode ISO-8859-10 Latin 6 Nordic (28600)
         
@@ -585,6 +645,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("iso8859_10")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_iso8859_11(self):
         """Encode ISO-8859-11 Latin/Thai (28601)
         
@@ -596,6 +657,7 @@ class Language(ChepyCore):
         )
         return self
 
+    @ChepyDecorators.call_stack
     def decode_iso8859_11(self):
         """Decode ISO-8859-11 Latin/Thai (28601)
         
@@ -605,6 +667,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("iso8859_11")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_iso8859_13(self):
         """Encode ISO-8859-13 Latin 7 Baltic Rim (28603)
         
@@ -616,6 +679,7 @@ class Language(ChepyCore):
         )
         return self
 
+    @ChepyDecorators.call_stack
     def decode_iso8859_13(self):
         """Decode ISO-8859-13 Latin 7 Baltic Rim (28603)
         
@@ -625,6 +689,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("iso8859_13")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_iso8859_14(self):
         """Encode ISO-8859-14 Latin 8 Celtic (28604)
         
@@ -636,6 +701,7 @@ class Language(ChepyCore):
         )
         return self
 
+    @ChepyDecorators.call_stack
     def decode_iso8859_14(self):
         """Decode ISO-8859-14 Latin 8 Celtic (28604)
         
@@ -645,6 +711,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("iso8859_14")
         return self
 
+    @ChepyDecorators.call_stack
     def encode_iso8859_15(self):
         """Encode ISO-8859-15 Latin 9 (28605)
         
@@ -656,6 +723,7 @@ class Language(ChepyCore):
         )
         return self
 
+    @ChepyDecorators.call_stack
     def decode_iso8859_15(self):
         """Decode ISO-8859-15 Latin 9 (28605)
         
@@ -665,6 +733,7 @@ class Language(ChepyCore):
         self.state = self._convert_to_bytes().decode("iso8859_15")
         return self
 
+    @ChepyDecorators.call_stack
     def remove_diacritics(self):
         """Replaces accented characters latin character equivalent.
         
@@ -676,6 +745,7 @@ class Language(ChepyCore):
         )
         return self
 
+    @ChepyDecorators.call_stack
     def unicode_to_str(self):
         """Escape any \\u characters to its proper unicode representation
         
