@@ -1,11 +1,15 @@
+import collections
+import socket
+import ssl
 import ipaddress
 import regex as re
 import urllib.parse as _py_urlparse
 from ua_parser.user_agent_parser import Parse as _uap_parse
-from ..core import ChepyCore
+from ..core import ChepyCore, ChepyDecorators
 
 
 class Networking(ChepyCore):
+    @ChepyDecorators.call_stack
     def defang_url(self):
         """Make a URL harmless
         
@@ -25,6 +29,7 @@ class Networking(ChepyCore):
         self.state = re.sub(r"\.", "[.]", self._convert_to_str())
         return self
 
+    @ChepyDecorators.call_stack
     def refang_url(self):
         """Refangs a URL so that it is clickable
         
@@ -39,6 +44,7 @@ class Networking(ChepyCore):
         self.state = re.sub(r"\[\.\]", ".", self._convert_to_str())
         return self
 
+    @ChepyDecorators.call_stack
     def defang_ip(self):
         """Make an IP address harmless
         
@@ -62,6 +68,7 @@ class Networking(ChepyCore):
             self.state = re.sub(r"\.|:", "[.]", self._convert_to_str())
         return self
 
+    @ChepyDecorators.call_stack
     def refang_ip(self):
         """Refangs an IP address
         
@@ -75,6 +82,7 @@ class Networking(ChepyCore):
         self.state = re.sub(r"\[\.\]|\[\:\]", ".", self._convert_to_str())
         return self
 
+    @ChepyDecorators.call_stack
     def parse_user_agent(self):
         """Parse a User-Agent string.
         
@@ -102,6 +110,7 @@ class Networking(ChepyCore):
         self.state = _uap_parse(self._convert_to_str())
         return self
 
+    @ChepyDecorators.call_stack
     def parse_uri(self):
         """Parse a URI
         
@@ -130,6 +139,7 @@ class Networking(ChepyCore):
         }
         return self
 
+    @ChepyDecorators.call_stack
     def parse_ip_range(self):
         """Enumerate IP address in a CIDR range
         
@@ -151,6 +161,7 @@ class Networking(ChepyCore):
         ]
         return self
 
+    @ChepyDecorators.call_stack
     def parse_ipv6(self):
         """Get longhand and shorthand of IPv6
         
@@ -167,3 +178,44 @@ class Networking(ChepyCore):
         ip = ipaddress.ip_address(self._convert_to_str())
         self.state = {"long": ip.exploded, "short": ip.compressed}
         return self
+
+    @ChepyDecorators.call_stack
+    def get_ssl_cert(self, port: int = 443):
+        """Get the server side SSL certificate for a domain
+        
+        Args:
+            port (int, optional): Server port. Defaults to 443.
+        
+        Returns:
+            Chepy: The Chepy object
+
+        Examples:
+            >>> Chepy('google.com').get_ssl_cert().o
+            {
+                'subject': {
+                    'commonName': '*.google.com',
+                    'organizationName': 'Google LLC',
+                ...
+                'caIssuers': ('http://pki.goog/gsr2/GTS1O1.crt',),
+                'crlDistributionPoints': ('http://crl.pki.goog/GTS1O1.crl',)
+            }
+        """
+        domain = re.sub("^\w+://", "", self._convert_to_str())
+        with socket.create_connection((domain, port)) as sock:
+            context = ssl.create_default_context()
+            with context.wrap_socket(sock, server_hostname=domain) as sslsock:
+                cert = sslsock.getpeercert()
+                final = {}
+                for key in cert.keys():
+                    if key == "subject" or key == "issuer":
+                        final[key] = dict(
+                            collections.ChainMap(*list(map(dict, cert[key])))
+                        )
+                    elif key == "subjectAltName":
+                        final[key] = list(
+                            map(lambda x: dict([x]), cert["subjectAltName"])
+                        )
+                    else:
+                        final[key] = cert[key]
+                self.state = final
+                return self
